* c-typeck.c, cfgexpand.c, ddg.c, ddg.h, df.c, fold-const.c,
authorkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>
Sat, 26 Jun 2004 05:03:55 +0000 (05:03 +0000)
committerkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>
Sat, 26 Jun 2004 05:03:55 +0000 (05:03 +0000)
gcov.c, gimplify.c, modulo-sched.c, passes.c, tree-cfg.c,
tree-mudflap.c, tree-nrv.c, tree-outof-ssa.c, tree-ssa-dom.c,
tree-ssa-dse.c, tree-ssa-operands.c, tree-ssa-pre.c,
tree-tailcall.c: Fix comment typos.  Follow spelling
conventions.

git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@83703 138bc75d-0d04-0410-961f-82ee72b054a4

20 files changed:
gcc/ChangeLog
gcc/c-typeck.c
gcc/cfgexpand.c
gcc/ddg.c
gcc/ddg.h
gcc/df.c
gcc/fold-const.c
gcc/gcov.c
gcc/gimplify.c
gcc/modulo-sched.c
gcc/passes.c
gcc/tree-cfg.c
gcc/tree-mudflap.c
gcc/tree-nrv.c
gcc/tree-outof-ssa.c
gcc/tree-ssa-dom.c
gcc/tree-ssa-dse.c
gcc/tree-ssa-operands.c
gcc/tree-ssa-pre.c
gcc/tree-tailcall.c

index adc5748..b22693a 100644 (file)
@@ -1,3 +1,12 @@
+2004-06-26  Kazu Hirata  <kazu@cs.umass.edu>
+
+       * c-typeck.c, cfgexpand.c, ddg.c, ddg.h, df.c, fold-const.c,
+       gcov.c, gimplify.c, modulo-sched.c, passes.c, tree-cfg.c,
+       tree-mudflap.c, tree-nrv.c, tree-outof-ssa.c, tree-ssa-dom.c,
+       tree-ssa-dse.c, tree-ssa-operands.c, tree-ssa-pre.c,
+       tree-tailcall.c: Fix comment typos.  Follow spelling
+       conventions.
+
 2004-06-25  Eric Christopher  <echristo@redhat.com>
 
        * config/mips/mips.md: Add back scheduling exclusion info.
index ededd61..2a2c254 100644 (file)
@@ -6490,7 +6490,7 @@ c_finish_if_stmt (location_t if_locus, tree cond, tree then_block,
     {
       tree inner_if = then_block;
 
-      /* We know from the grammer productions that there is an IF nested
+      /* We know from the grammar productions that there is an IF nested
         within THEN_BLOCK.  Due to labels and c99 conditional declarations,
         it might not be exactly THEN_BLOCK, but should be the last
         non-container statement within.  */
@@ -6547,7 +6547,7 @@ c_finish_if_stmt (location_t if_locus, tree cond, tree then_block,
 /* Emit a general-purpose loop construct.  START_LOCUS is the location of
    the beginning of the loop.  COND is the loop condition.  COND_IS_FIRST
    is false for DO loops.  INCR is the FOR increment expression.  BODY is
-   the statement controled by the loop.  BLAB is the break label.  CLAB is
+   the statement controlled by the loop.  BLAB is the break label.  CLAB is
    the continue label.  Everything is allowed to be NULL.  */
 
 void
index d9be28b..1576566 100644 (file)
@@ -389,7 +389,7 @@ set_save_expr_context (tree *tp,
    We do conversion per basic block and preserve/update the tree CFG.
    This implies we have to do some magic as the CFG can simultaneously
    consist of basic blocks containing RTL and GIMPLE trees.  This can
-   confuse the CFG hooks, so be curefull to not manipulate CFG during
+   confuse the CFG hooks, so be careful to not manipulate CFG during
    the expansion.  */
 
 static void
index 5ab8f0d..00c78f9 100644 (file)
--- a/gcc/ddg.c
+++ b/gcc/ddg.c
@@ -383,7 +383,7 @@ build_intra_loop_deps (ddg_ptr g)
   get_block_head_tail (g->bb->index, &head, &tail);
   sched_analyze (&tmp_deps, head, tail);
 
-  /* Build intra-loop data dependecies using the scheduler dependecy
+  /* Build intra-loop data dependencies using the scheduler dependency
      analysis.  */
   for (i = 0; i < g->num_nodes; i++)
     {
@@ -509,7 +509,7 @@ create_ddg (basic_block bb, struct df *df, int closing_branch_deps)
   if (!g->closing_branch)
     abort ();  /* Found no branch in DDG.  */
 
-  /* Build the data dependecy graph.  */
+  /* Build the data dependency graph.  */
   build_intra_loop_deps (g);
   build_inter_loop_deps (g, df);
   return g;
index b524d7b..c958aec 100644 (file)
--- a/gcc/ddg.h
+++ b/gcc/ddg.h
@@ -92,7 +92,7 @@ struct ddg_edge
   /* REG or MEM dependency.  */
   dep_data_type data_type;
 
-  /* Latency of the depedency.  */
+  /* Latency of the dependency.  */
   int latency;
 
   /* The distance: number of loop iterations the dependency crosses.  */
index 2fa65c3..e25c37a 100644 (file)
--- a/gcc/df.c
+++ b/gcc/df.c
@@ -2348,7 +2348,7 @@ prune_to_subcfg (int list[], unsigned len, bitmap blocks)
   return last;
 }
 
-/* Alternative entry point to the analysis.  Analyse just the part of the cfg
+/* Alternative entry point to the analysis.  Analyze just the part of the cfg
    graph induced by BLOCKS.
    
    TODO I am not quite sure how to avoid code duplication with df_analyze_1
index 343662a..24bde0f 100644 (file)
@@ -3717,7 +3717,7 @@ make_range (tree exp, int *pin_p, tree *plow, tree *phigh)
 
 
          /* If we're converting arg0 from an unsigned type, to exp,
-            a signed type,  we will be doing the compairson as unsigned.
+            a signed type,  we will be doing the comparison as unsigned.
             The tests above have already verified that LOW and HIGH
             are both positive.
 
index 172f9e8..6fd4969 100644 (file)
@@ -1738,7 +1738,7 @@ accumulate_line_counts (source_t *src)
     }
 }
 
-/* Ouput information about ARC number IX.  Returns nonzero if
+/* Output information about ARC number IX.  Returns nonzero if
    anything is output.  */
 
 static int
index 38bd2d7..347e946 100644 (file)
@@ -2641,7 +2641,7 @@ gimplify_modify_expr (tree *expr_p, tree *pre_p, tree *post_p, bool want_value)
   return ret;
 }
 
-/*  Subroutine of above to do simplications of MODIFY_EXPRs based on
+/*  Subroutine of above to do simplifications of MODIFY_EXPRs based on
     the code of the RHS.  We loop for as long as we can do something.  */
 
 static enum gimplify_status
index 1c7978a..68eeb36 100644 (file)
@@ -217,7 +217,7 @@ typedef struct node_sched_params
 
 \f
 /* The following three functions are copied from the current scheduler
-   code in order to use sched_analyze() for computing the dependecies.
+   code in order to use sched_analyze() for computing the dependencies.
    They are used when initializing the sched_info structure.  */
 static const char *
 sms_print_insn (rtx insn, int aligned ATTRIBUTE_UNUSED)
@@ -386,7 +386,7 @@ set_node_sched_params (ddg_ptr g)
                                sizeof (struct node_sched_params));
 
   /* Set the pointer of the general data of the node to point to the
-     appropriate sched_params strcture.  */
+     appropriate sched_params structure.  */
   for (i = 0; i < g->num_nodes; i++)
     {
       /* Watch out for aliasing problems?  */
@@ -447,7 +447,7 @@ calculate_maxii (ddg_ptr g)
    of the register live range is more than ii; the number of moves is
    determined according to the following equation:
                SCHED_TIME (use) - SCHED_TIME (def)   { 1 broken loop-carried
-   nreg_moves = ----------------------------------- - {   dependecnce.
+   nreg_moves = ----------------------------------- - {   dependence.
                              ii                      { 0 if not.
    This handles the modulo-variable-expansions (mve's) needed for the ps.  */
 static void
@@ -832,7 +832,7 @@ sms_schedule (FILE *dump_file)
   else
     issue_rate = 1;
 
-  /* Initilize the scheduler.  */
+  /* Initialize the scheduler.  */
   current_sched_info = &sms_sched_info;
   sched_init (NULL);
 
@@ -1526,7 +1526,7 @@ calculate_order_params (ddg_ptr g, int mii ATTRIBUTE_UNUSED)
   node_order_params_arr = (nopa) xcalloc (num_nodes,
                                          sizeof (struct node_order_params));
 
/* Set the aux pointer of each node to point to its order_params strcture.  */
   for (u = 0; u < num_nodes; u++)
     g->nodes[u].aux.info = &node_order_params_arr[u];
 
index 678dd7d..f6e1ad5 100644 (file)
@@ -758,7 +758,7 @@ rest_of_handle_sched (void)
       close_dump_file (DFI_sms, print_rtl, get_insns ());
 
 
-      /* Update the life information, becuase we add pseudos.  */
+      /* Update the life information, because we add pseudos.  */
       max_regno = max_reg_num ();
       allocate_reg_info (max_regno, FALSE, FALSE);
       update_life_info_in_dirty_blocks (UPDATE_LIFE_GLOBAL_RM_NOTES,
index ca8afed..6855d71 100644 (file)
@@ -3924,7 +3924,7 @@ thread_jumps (void)
               dest = dest->succ->dest)
            {
              /* An infinite loop detected.  We redirect the edge anyway, so
-                that the loop is shrinked into single basic block.  */
+                that the loop is shrunk into single basic block.  */
              if (!bb_ann (dest)->forwardable)
                break;
 
index 4d9e77b..dcde2ac 100644 (file)
@@ -819,7 +819,7 @@ mx_register_decls (tree decl, tree *stmt_list)
             {
               /* Oh no ... it's probably a variable-length array (VLA).
                  The size and address cannot be computed by merely
-                 looking at the DECL.  See gimplfiy_decl_stmt for the
+                 looking at the DECL.  See gimplify_decl_stmt for the
                  method by which VLA declarations turn into calls to
                  BUILT_IN_STACK_ALLOC.  We assume that multiple
                  VLAs declared later in the same block get allocation 
index 4732e9c..761bb03 100644 (file)
@@ -85,7 +85,7 @@ finalize_nrv_r (tree *tp, int *walk_subtrees, void *data)
   else if (TREE_CODE (*tp) == RETURN_EXPR)
     TREE_OPERAND (*tp, 0) = dp->result;
 
-  /* Othewise replace all occurrences of VAR with RESULT.  */
+  /* Otherwise replace all occurrences of VAR with RESULT.  */
   else if (*tp == dp->var)
     *tp = dp->result;
 
index 517e2b8..7d195cc 100644 (file)
@@ -1183,7 +1183,7 @@ coalesce_vars (var_map map, tree_live_info_p liveinfo)
    it is replaced with the RHS of the defining expression.  */
 
 
-/* Dependancy list element.  This can contain either a partition index or a
+/* Dependency list element.  This can contain either a partition index or a
    version number, depending on which list it is in.  */
 
 typedef struct value_expr_d 
@@ -1208,7 +1208,7 @@ typedef struct temp_expr_table_d
   value_expr_p pending_dependence;
 } *temp_expr_table_p;
 
-/* Used to indicate a dependancy on V_MAY_DEFs.  */
+/* Used to indicate a dependency on V_MAY_DEFs.  */
 #define VIRTUAL_PARTITION(table)       (table->virtual_partition)
 
 static temp_expr_table_p new_temp_expr_table (var_map);
@@ -1398,8 +1398,8 @@ remove_value_from_list (value_expr_p *list, int value)
 }
 
 
-/* Add a dependancy between the def of ssa VERSION and VAR.  if VAR is 
-   replaceable by an expression, add a dependance each of the elements of the 
+/* Add a dependency between the def of ssa VERSION and VAR.  If VAR is 
+   replaceable by an expression, add a dependence each of the elements of the 
    expression.  These are contained in the pending list.  TAB is the
    expression table.  */
 
@@ -1503,7 +1503,7 @@ check_replaceable (temp_expr_table_p tab, tree stmt)
 
   version = SSA_NAME_VERSION (def);
 
-  /* Add this expression to the dependancy list for each use partition.  */
+  /* Add this expression to the dependency list for each use partition.  */
   for (i = 0; i < num_use_ops; i++)
     {
       var = USE_OP (uses, i);
@@ -1535,7 +1535,7 @@ finish_expr (temp_expr_table_p tab, int version, bool replace)
   value_expr_p info, tmp;
   int partition;
 
/* Remove this expression from its dependent lists.  The partition dependance
      list is retained and transfered later to whomever uses this version.  */
   for (info = (value_expr_p) tab->version_info[version]; info; info = tmp)
     {
@@ -1551,7 +1551,7 @@ finish_expr (temp_expr_table_p tab, int version, bool replace)
         abort ();
 #endif
       free_value_expr (tab, tmp);
-      /* Only clear the bit when the dependancy list is emptied via 
+      /* Only clear the bit when the dependency list is emptied via 
          a replacement. Otherwise kill_expr will take care of it.  */
       if (!(tab->partition_dep_list[partition]) && replace)
         bitmap_clear_bit (tab->partition_in_use, partition);
@@ -1610,7 +1610,7 @@ kill_expr (temp_expr_table_p tab, int partition, bool clear_bit)
 {
   value_expr_p ptr;
 
-  /* Mark every active expr dependant on this var as not replaceable.  */
+  /* Mark every active expr dependent on this var as not replaceable.  */
   while ((ptr = tab->partition_dep_list[partition]) != NULL)
     finish_expr (tab, ptr->value, false);
 
@@ -1619,7 +1619,7 @@ kill_expr (temp_expr_table_p tab, int partition, bool clear_bit)
 }
 
 
-/* This function kills all expressions in TAB which are dependant on virtual 
+/* This function kills all expressions in TAB which are dependent on virtual 
    DEFs.  CLEAR_BIT determines whether partition_in_use gets cleared.  */
 
 static inline void
@@ -1680,7 +1680,7 @@ find_replaceable_in_bb (temp_expr_table_p tab, basic_block bb)
       if (!ann->has_volatile_ops)
        check_replaceable (tab, stmt);
 
-      /* Free any unused dependancy lists.  */
+      /* Free any unused dependency lists.  */
       while ((p = tab->pending_dependence))
        {
          tab->pending_dependence = p->next;
index 627ba25..eadef0d 100644 (file)
@@ -649,7 +649,7 @@ tree_ssa_dominator_optimize (void)
   if (dump_file && (dump_flags & TDF_STATS))
     dump_dominator_optimization_stats (dump_file);
 
-  /* We emptyed the hash table earlier, now delete it completely.  */
+  /* We emptied the hash table earlier, now delete it completely.  */
   htab_delete (avail_exprs);
 
   /* It is not necessary to clear CURRDEFS, REDIRECTION_EDGES, VRP_DATA,
@@ -3361,7 +3361,7 @@ avail_expr_eq (const void *p1, const void *p2)
   return false;
 }
 
-/* Given STMT and a pointer to the block local defintions BLOCK_DEFS_P,
+/* Given STMT and a pointer to the block local definitions BLOCK_DEFS_P,
    register register all objects set by this statement into BLOCK_DEFS_P
    and CURRDEFS.  */
 
index 7902e14..ce28694 100644 (file)
@@ -55,7 +55,7 @@ Boston, MA 02111-1307, USA.  */
 
    It may help to think of this as first moving the earlier store to
    the point immediately before the later store.  Again, the single
-   use of the virtual defintion and the post-dominance relationship
+   use of the virtual definition and the post-dominance relationship
    ensure that such movement would be safe.  Clearly if there are 
    back to back stores, then the second is redundant.
 
index 68da398..3129b9a 100644 (file)
@@ -741,7 +741,7 @@ get_stmt_operands (tree stmt)
   prev_vops.vuse_ops = VUSE_OPS (ann);
   prev_vops.v_must_def_ops = V_MUST_DEF_OPS (ann);
 
-  /* Dont free the previous values to memory since we're still using them.  */
+  /* Don't free the previous values to memory since we're still using them.  */
   free_v_may_defs (&(ann->v_may_def_ops), false);
   free_vuses (&(ann->vuse_ops), false);
   free_v_must_defs (&(ann->v_must_def_ops), false);
index 5c32bc2..45ac874 100644 (file)
@@ -1151,7 +1151,7 @@ find_or_generate_expression (basic_block block, tree expr, tree stmts)
   /* Depending on the order we process DOM branches in, the value
      may not have propagated to all the dom children yet during
      this iteration.  In this case, the value will always be in
-     the NEW_SETS for us already, having been propogated from our
+     the NEW_SETS for us already, having been propagated from our
      dominator.  */
   if (genop == NULL)
     genop = find_leader (NEW_SETS (block), expr);
index 7a703d5..6036cfa 100644 (file)
@@ -210,7 +210,7 @@ independent_of_stmt_p (tree expr, tree at, block_stmt_iterator bsi)
       at = SSA_NAME_DEF_STMT (expr);
       bb = bb_for_stmt (at);
 
/* The default defininition or defined before the chain.  */
       if (!bb || !bb->aux)
        break;
@@ -1526,7 +1526,7 @@ calculate_order_params (ddg_ptr g, int mii ATTRIBUTE_UNUSED)
                                          sizeof (struct node_order_params));
 
-  /* Set the aux pointer of each node to point to its order_params strcture.  */
+  /* Set the aux pointer of each node to point to its order_params structure.  */
   for (u = 0; u < num_nodes; u++)
     g->nodes[u].aux.info = &node_order_params_arr[u];
@@ -1535,7 +1535,7 @@ finish_expr (temp_expr_table_p tab, int version, bool replace)
   int partition;
 
-  /* Remove this expression from its dependent lists.  The partition dependance
+  /* Remove this expression from its dependent lists.  The partition dependence
      list is retained and transfered later to whomever uses this version.  */
   for (info = (value_expr_p) tab->version_info[version]; info; info = tmp)
@@ -210,7 +210,7 @@ independent_of_stmt_p (tree expr, tree at, block_stmt_iterator bsi)
       bb = bb_for_stmt (at);
 
-      /* The default defininition or defined before the chain.  */
+      /* The default definition or defined before the chain.  */
       if (!bb || !bb->aux)
        break;